@@ -92,7 +92,7 @@ def _add_mysql(table: str, field: str, type_: str, unsigned=True):
     return sql
 
 
-class mysql(Base):
+class MySQL(Base):
     """
                      MySQL
         dms - DataBase Management System
@@ -101,7 +101,7 @@ class mysql(Base):
     def __init__(self, host, database,
                  port=3306, user="root", password=""):
 
-        super(mysql, self).__init__()
+        super(MySQL, self).__init__()
         self.host = host
         self.database = database
         self.port = port
@@ -139,7 +139,7 @@ class mysql(Base):
         with self.connection.cursor() as cursor:
             try:
                 cursor.execute(_add_mysql(table, field, type_, unsigned))
-            except pymysql.err.OperationalError as ex:
+            except pymysql.err.OperationalError:
                 pass  # catching duplication of fields
 
     def puts(self, table: str, column_values: dict, unsigned=True):
@@ -291,7 +291,6 @@ class mysql(Base):
             table = PrettyTable()
 
             field_names = []
-            values_list = []
 
             cursor.execute(sql_describe)
 
@@ -321,7 +320,6 @@ class mysql(Base):
             table = PrettyTable()
 
             field_names = []
-            values_list = []
 
             cursor.execute(sql_describe)
 
@@ -345,7 +343,7 @@ class mysql(Base):
 
         self.connection.ping()  # reconnecting mysql
         with self.connection.cursor() as cursor:
-            cursor.execute(sql, values)
+            cursor.execute(sub_sql, values)
             rows = cursor.fetchall()
 
         return rows
@@ -355,7 +353,7 @@ class mysql(Base):
 
         self.connection.ping()  # reconnecting mysql
         with self.connection.cursor() as cursor:
-            cursor.execute(sql, values)
+            cursor.execute(sub_sql, values)
             rows = cursor.fetchall()
 
         return rows
@@ -366,34 +364,30 @@ class mysql(Base):
             field_ids = ", ".join(map(str, field_ids))
             sql = f"DELETE FROM `{table}` WHERE `id` IN({field_ids})"
             cursor.execute(sql)
-            self.store()
 
     def trash_sql(self, table: str, sql: str, *values):
         self.connection.ping()  # reconnecting mysql
         with self.connection.cursor() as cursor:
             sub_sql = f"DELETE FROM `{table}` WHERE {sql}"
             cursor.execute(sub_sql, values)
-            self.store()
 
     def wipe(self, table: str):
         self.connection.ping()  # reconnecting mysql
         with self.connection.cursor() as cursor:
             sql = f"TRUNCATE `{table}`"
             cursor.execute(sql)
-            self.store()
 
     def nuke(self, table: str):
         self.connection.ping()  # reconnecting mysql
         with self.connection.cursor() as cursor:
             sql = f"DROP TABLE IF EXISTS `{table}`"
             cursor.execute(sql)
-            self.store()
 
 
-class sqlite(Base):
+class SQLite(Base):
 
     def __init__(self, database: str):
-        super(sqlite, self).__init__()
+        super(SQLite, self).__init__()
 
         # host=None, port=None, user=None, password=None, database=None
         try:
@@ -587,4 +581,4 @@ class sqlite(Base):
     def nuke(self, table: str):
         with self.connection:
             sql = f"DROP TABLE IF EXISTS `{table}`"
-            self.cursor.execute(sql)
+            self.cursor.execute(sql)
\ No newline at end of file
